from llm_foundation import logger


def main():
    logger.info(f"Hello World from LLM_Foundation!")


if __name__ == "__main__":
    main()